@@ -43,7 +43,7 @@
 #define GPD_PAGE_PILOT_TWO 5
 #define GPD_PAGE_FINISH 6
 
-static GtkObjectClass *parent_class = NULL;
+static GObjectClass *parent_class = NULL;
 
 struct _GnomePilotAssistantPrivate 
 {
@@ -93,9 +93,7 @@ struct _GnomePilotAssistantPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
-#ifdef PILOT_LINK_0_12
 	GtkWidget *pilot_charset;
-#endif
 	GtkWidget *pilot_charset_label;
 	GtkWidget *pilot_charset_combo;
 };
@@ -134,7 +132,7 @@ static void gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device,
 static void gpd_system_info_requested (GnomePilotClient *gpc,
  const gchar *device, const GNOME_Pilot_SysInfo *sysinfo, gpointer user_data);
 
-static void gpd_destroy (GtkObject *object);
+static void gpd_dispose (GObject *object);
 
 GType
 gnome_pilot_assistant_get_type (void)
@@ -156,7 +154,7 @@ gnome_pilot_assistant_get_type (void)
         (GInstanceInitFunc) init,
       };
       
-      type = g_type_register_static (gtk_object_get_type (), "GnomePilotAssistant", &info, 0);
+      type = g_type_register_static (g_object_get_type (), "GnomePilotAssistant", &info, 0);
     }
 
   return type;
@@ -165,13 +163,13 @@ gnome_pilot_assistant_get_type (void)
 static void
 class_init (GnomePilotAssistantClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek (gtk_object_get_type ());
+	parent_class = g_type_class_peek (g_object_get_type ());
 
-	object_class->destroy = gpd_destroy;
+	object_class->dispose = gpd_dispose;
 }
 
 static void
@@ -225,22 +223,22 @@ init (GnomePilotAssistant *gpd)
 
 
 
-GtkObject *
+GObject *
 gnome_pilot_assistant_new (GnomePilotClient *gpc)
 {
 	GnomePilotAssistant *gpd;
-	GtkObject *obj;
+	GObject *obj;
 	
-	obj = GTK_OBJECT(g_type_create_instance (GNOME_PILOT_TYPE_ASSISTANT));
+	obj = G_OBJECT(g_type_create_instance (GNOME_PILOT_TYPE_ASSISTANT));
 	
 	gpd = GNOME_PILOT_ASSISTANT (obj);
 	gpd->priv->gpc = gpc;
 
-	g_signal_connect   (GTK_OBJECT (gpc), "completed_request",
+	g_signal_connect   (G_OBJECT (gpc), "completed_request",
 			    G_CALLBACK (gpd_request_completed), gpd);
-	g_signal_connect   (GTK_OBJECT (gpc), "user_info",
+	g_signal_connect   (G_OBJECT (gpc), "user_info",
 			    G_CALLBACK (gpd_userinfo_requested), gpd);
-	g_signal_connect   (GTK_OBJECT (gpc), "system_info",
+	g_signal_connect   (G_OBJECT (gpc), "system_info",
 			    G_CALLBACK (gpd_system_info_requested), gpd);
 
 	return obj;
@@ -302,21 +300,19 @@ get_widgets (GnomePilotAssistant *gpd)
 	model = GTK_TREE_MODEL(gtk_builder_get_object (priv->ui,
 		"assistant_device_port_store"));
 	gtk_combo_box_set_model (GTK_COMBO_BOX (priv->device_port_combo), model);
-	gtk_combo_box_entry_set_text_column(
-	    GTK_COMBO_BOX_ENTRY (priv->device_port_combo), 0);
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (
+		priv->device_port_combo), 0);
 	gtk_cell_layout_clear(GTK_CELL_LAYOUT(priv->device_port_combo));
 	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->device_port_combo),
 	    renderer, TRUE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->device_port_combo),
 	    renderer, "text", 0);
-#ifdef PILOT_LINK_0_12
 	/* usb: (libusb) pseudo-device is available from pilot-link 0.12.0 */
 	gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, "usb:", -1);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->device_usb), 1);
 
-#endif
 
 	gtk_combo_box_set_active(
 	    GTK_COMBO_BOX (priv->device_port_combo), 0);
@@ -334,10 +330,8 @@ get_widgets (GnomePilotAssistant *gpd)
 	priv->pilot_basedir = GW ("assistant_pilot_basedir_entry");
 	priv->pilot_charset_label = GW ("assistant_pilot_charset_label");
 	priv->pilot_charset_combo = GW ("assistant_pilot_charset_combo");
-#ifdef PILOT_LINK_0_12
 	priv->pilot_charset = gtk_bin_get_child (
 	    GTK_BIN(priv->pilot_charset_combo));
-#endif
 
 
 #undef GW
@@ -359,9 +353,7 @@ get_widgets (GnomePilotAssistant *gpd)
 		&& priv->sync_label
 		&& priv->pilot_name
 		&& priv->pilot_basedir
-#ifdef PILOT_LINK_0_12
 		&& priv->pilot_charset
-#endif
 		&& priv->pilot_charset_label
 		&& priv->pilot_charset_combo);
 }
@@ -386,9 +378,7 @@ map_widgets (GnomePilotAssistant *gpd)
 	g_object_set_data (G_OBJECT (gpd), "pilotid", priv->pilot_id);
 	g_object_set_data (G_OBJECT (gpd), "pilotname", priv->pilot_name);
 	g_object_set_data (G_OBJECT (gpd), "basedir", priv->pilot_basedir);
-#ifdef PILOT_LINK_0_12
 	g_object_set_data (G_OBJECT (gpd), "charset", priv->pilot_charset);
-#endif
 }
 
 static void 
@@ -399,12 +389,12 @@ init_widgets (GnomePilotAssistant *gpd)
 	priv = gpd->priv;
 
 	/* Main signals */
-	g_signal_connect   (GTK_OBJECT (priv->assistant), "delete_event",
+	g_signal_connect   (G_OBJECT (priv->assistant), "delete_event",
 	    G_CALLBACK (gpd_delete_window), gpd);
 
-	g_signal_connect   (GTK_OBJECT (priv->assistant), "cancel",
+	g_signal_connect   (G_OBJECT (priv->assistant), "cancel",
 	    G_CALLBACK (gpd_canceled), gpd);
-	//	g_signal_connect   (GTK_OBJECT (priv->assistant), "help",
+	//	g_signal_connect   (G_OBJECT (priv->assistant), "help",
 	//   G_CALLBACK (gpd_help), gpd);
 
 
@@ -416,28 +406,28 @@ init_widgets (GnomePilotAssistant *gpd)
 
 
 	/* Other widget signals */
-	g_signal_connect   (GTK_OBJECT (priv->device_name),"changed",
+	g_signal_connect   (G_OBJECT (priv->device_name),"changed",
 			    G_CALLBACK (gpd_device_info_check), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->device_port),"insert-text",
+	g_signal_connect   (G_OBJECT (priv->device_port),"insert-text",
 			    G_CALLBACK (insert_device_callback), NULL);
-	g_signal_connect   (GTK_OBJECT (priv->device_network), "toggled",
+	g_signal_connect   (G_OBJECT (priv->device_network), "toggled",
 			    G_CALLBACK (network_device_toggled_callback), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->device_bluetooth), "toggled",
+	g_signal_connect   (G_OBJECT (priv->device_bluetooth), "toggled",
 			    G_CALLBACK (network_device_toggled_callback), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->device_port),"changed",
+	g_signal_connect   (G_OBJECT (priv->device_port),"changed",
 			    G_CALLBACK (gpd_device_info_check), gpd);
 
-	g_signal_connect   (GTK_OBJECT (priv->pilot_info_no),"toggled",
+	g_signal_connect   (G_OBJECT (priv->pilot_info_no),"toggled",
 			    G_CALLBACK (gpd_pilot_info_button), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->pilot_username),"insert-text",
+	g_signal_connect   (G_OBJECT (priv->pilot_username),"insert-text",
 			    G_CALLBACK (insert_username_callback), NULL);
-	g_signal_connect   (GTK_OBJECT (priv->pilot_username),"changed",
+	g_signal_connect   (G_OBJECT (priv->pilot_username),"changed",
 			    G_CALLBACK (gpd_pilot_info_check), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->pilot_id),"insert-text",
+	g_signal_connect   (G_OBJECT (priv->pilot_id),"insert-text",
 			    G_CALLBACK (insert_numeric_callback), NULL);
-	g_signal_connect   (GTK_OBJECT (priv->pilot_id),"changed",
+	g_signal_connect   (G_OBJECT (priv->pilot_id),"changed",
 			    G_CALLBACK (gpd_pilot_info_check), gpd);
-	g_signal_connect   (GTK_OBJECT (priv->pilot_name),"changed",
+	g_signal_connect   (G_OBJECT (priv->pilot_name),"changed",
 			    G_CALLBACK (gpd_pilot_name_check), gpd);
 
 }
@@ -456,8 +446,8 @@ fill_widgets (GnomePilotAssistant *gpd)
 	gtk_entry_set_text (GTK_ENTRY (priv->device_name), str);
 	g_free (str);
 	set_widget_visibility_by_type(gpd,
-	    (GTK_TOGGLE_BUTTON(priv->device_network)->active ||
-		GTK_TOGGLE_BUTTON(priv->device_bluetooth)->active) ?
+	    (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->device_network)) ||
+		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->device_bluetooth))) ?
 	    PILOT_DEVICE_NETWORK : PILOT_DEVICE_SERIAL);
 	
 	/* First pilot page */
@@ -472,13 +462,8 @@ fill_widgets (GnomePilotAssistant *gpd)
 	
 	str2 = g_build_filename (g_get_home_dir (), str, NULL);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_basedir), str2);
-#ifndef PILOT_LINK_0_12
-	gtk_widget_set_sensitive(priv->pilot_charset_label, FALSE);
-	gtk_widget_set_sensitive(priv->pilot_charset_combo, FALSE);
-#else
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_charset),
 	    get_default_pilot_charset());
-#endif
 
 	g_free (str);
 	g_free (str2);
@@ -498,7 +483,7 @@ gnome_pilot_assistant_run_and_close (GnomePilotAssistant *gpd)
 
 	result = priv->finished;
 	
-	gtk_object_destroy (GTK_OBJECT (gpd));
+	g_object_unref (G_OBJECT (gpd));
 
 	return result;
 }
@@ -610,7 +595,7 @@ gpd_page_prepare (GtkAssistant *assistant, GtkWidget *page,
 		    gpd->priv->page_pilot_two, TRUE);
 		break;
 	case GPD_PAGE_FINISH:
-		g_signal_connect   (GTK_OBJECT (gpd->priv->assistant), "close",
+		g_signal_connect   (G_OBJECT (gpd->priv->assistant), "close",
 		    G_CALLBACK (gpd_finish_page_finished), gpd);
 
 	default:
@@ -692,7 +677,7 @@ gpd_cradle_page_next (GnomePilotAssistant *gpd)
 
 	/* check the device settings */
 	tmp_device = gpilot_device_new();
-	read_device_config(GTK_OBJECT(gpd), tmp_device);
+	read_device_config(G_OBJECT(gpd), tmp_device);
 	if (priv->errstr != NULL) {
 		g_free(priv->errstr);
 		priv->errstr = NULL;
@@ -724,14 +709,14 @@ gpd_sync_page_prepare (GnomePilotAssistant *gpd)
 
 	priv = gpd->priv;
 
-	read_device_config (GTK_OBJECT (gpd), priv->device);
+	read_device_config (G_OBJECT (gpd), priv->device);
 	
 	if (priv->state->devices == NULL)
 		priv->state->devices = g_list_append (priv->state->devices, priv->device);
 
-	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active) {
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (priv->pilot_info_no))) {
 		/* do send_to_pilot */
-		read_pilot_config (GTK_OBJECT (gpd), priv->pilot);
+		read_pilot_config (G_OBJECT (gpd), priv->pilot);
 		location = priv->device->type == PILOT_DEVICE_NETWORK ?
 		    "netsync" : (priv->device->type == PILOT_DEVICE_BLUETOOTH ?
 			"bluetooth" : priv->device->port);
@@ -824,9 +809,7 @@ gpd_pilot_page_two_next (GnomePilotAssistant *gpd)
 		priv->errstr = NULL;
 	}
 	return (!(check_base_directory (gtk_entry_get_text (GTK_ENTRY (priv->pilot_basedir)), &priv->errstr)
-#ifdef PILOT_LINK_0_12
 		&& check_pilot_charset (gtk_entry_get_text (GTK_ENTRY (priv->pilot_charset)), &priv->errstr)
-#endif
 		));
 }
 
@@ -838,7 +821,7 @@ gpd_finish_page_finished (GtkAssistant *assistant, gpointer data)
 	
 	priv = gpd->priv;
 	
-	read_pilot_config (GTK_OBJECT (gpd), priv->pilot);
+	read_pilot_config (G_OBJECT (gpd), priv->pilot);
 	priv->state->pilots = g_list_append (priv->state->pilots, priv->pilot);
 	
 	save_config_and_restart (priv->gpc, priv->state);
@@ -871,7 +854,7 @@ gpd_pilot_info_check (GtkEditable *editable, gpointer user_data)
 	
 	priv = gpd->priv;
 	
-	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active)
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (priv->pilot_info_no)))
 		ready = check_pilot_settings (gpd);
 
 	gtk_assistant_set_page_complete (GTK_ASSISTANT (priv->assistant),
@@ -901,8 +884,8 @@ gpd_pilot_info_button (GtkToggleButton *toggle, gpointer user_data)
 	
 	priv = gpd->priv;
 	
-	gtk_widget_set_sensitive (priv->pilot_info, toggle->active);
-	if (toggle->active)
+	gtk_widget_set_sensitive (priv->pilot_info, gtk_toggle_button_get_active(toggle));
+	if (gtk_toggle_button_get_active(toggle))
 		ready = check_pilot_settings (gpd);
 
 	gtk_assistant_set_page_complete (GTK_ASSISTANT (priv->assistant),
@@ -987,7 +970,7 @@ gpd_system_info_requested (GnomePilotClient *gpc,
 }
 
 static void
-gpd_destroy (GtkObject *object)
+gpd_dispose (GObject *object)
 {
 	GnomePilotAssistant *gpd = GNOME_PILOT_ASSISTANT (object);
 	GnomePilotAssistantPrivate *priv;
@@ -999,9 +982,6 @@ gpd_destroy (GtkObject *object)
 
 	g_signal_handlers_disconnect_matched (priv->gpc,
 	    G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, object);
-
-	if (GTK_OBJECT_CLASS (parent_class)->destroy)
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 static void
@@ -1015,10 +995,10 @@ network_device_toggled_callback (GtkRadioButton *btn, void *data)
 
 	/* toggled button could be bluetooth or network */
 	if(btn == GTK_RADIO_BUTTON(priv->device_network) &&
-	    GTK_TOGGLE_BUTTON(btn)->active) {
+	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(btn))) {
 		type = PILOT_DEVICE_NETWORK;
 	} else if (btn == GTK_RADIO_BUTTON(priv->device_bluetooth) &&
-	    GTK_TOGGLE_BUTTON(btn)->active) {
+	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(btn))) {
 		type = PILOT_DEVICE_BLUETOOTH;
 	} else {
 		type = PILOT_DEVICE_SERIAL;
