@@ -69,7 +69,7 @@ struct _GnomePilotCappletPrivate
 	GtkWidget *devices_delete;
 	GtkWidget *devices_popup;
 
-	GtkObject *pdialog;
+	GObject *pdialog;
 	GtkWidget *pilots_combo;
 	GtkWidget *pilots_username;
 	GtkWidget *conduit_treeview;
@@ -226,7 +226,6 @@ get_widgets (GnomePilotCapplet *gpcap)
 #define GW(name) GTK_WIDGET (gtk_builder_get_object (priv->ui, name))
 
 	gtk_window_set_title (GTK_WINDOW (gpcap), _("gnome-pilot Settings"));
-	gtk_dialog_set_has_separator (GTK_DIALOG (gpcap), FALSE);
 	gtk_dialog_add_button (GTK_DIALOG (gpcap),
 			       GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_dialog_add_button (GTK_DIALOG (gpcap),
@@ -235,7 +234,9 @@ get_widgets (GnomePilotCapplet *gpcap)
 	priv->notebook = GW ("CappletMain");
 
 	if (priv->notebook)
-		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (gpcap)->vbox), priv->notebook);
+		gtk_container_add (GTK_CONTAINER (
+			gtk_dialog_get_content_area (GTK_DIALOG (gpcap))),
+		    priv->notebook);
 
 	w = GW ("pilots_treeview");
 	priv->pilots_treeview = g_object_get_data (G_OBJECT (w), "treeview");
@@ -287,31 +288,31 @@ init_widgets (GnomePilotCapplet *gpcap)
 	priv = gpcap->priv;
 
 	/* Button signals */
-	g_signal_connect   (GTK_OBJECT (priv->pilots_add), "clicked",
+	g_signal_connect   (G_OBJECT (priv->pilots_add), "clicked",
 			    G_CALLBACK (gpcap_pilots_add), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->pilots_edit), "clicked",
+	g_signal_connect   (G_OBJECT (priv->pilots_edit), "clicked",
 			    G_CALLBACK (gpcap_pilots_edit), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->pilots_delete), "clicked",
+	g_signal_connect   (G_OBJECT (priv->pilots_delete), "clicked",
 			    G_CALLBACK (gpcap_pilots_delete), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->devices_add), "clicked",
+	g_signal_connect   (G_OBJECT (priv->devices_add), "clicked",
 			    G_CALLBACK (gpcap_devices_add), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->devices_edit), "clicked",
+	g_signal_connect   (G_OBJECT (priv->devices_edit), "clicked",
 			    G_CALLBACK (gpcap_devices_edit), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->devices_delete), "clicked",
+	g_signal_connect   (G_OBJECT (priv->devices_delete), "clicked",
 			    G_CALLBACK (gpcap_devices_delete), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->conduit_enable), "clicked",
+	g_signal_connect   (G_OBJECT (priv->conduit_enable), "clicked",
 			    G_CALLBACK (gpcap_conduits_enable), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->conduit_disable), "clicked",
+	g_signal_connect   (G_OBJECT (priv->conduit_disable), "clicked",
 			    G_CALLBACK (gpcap_conduits_disable), gpcap);
 
-	g_signal_connect   (GTK_OBJECT (priv->conduit_settings), "clicked",
+	g_signal_connect   (G_OBJECT (priv->conduit_settings), "clicked",
 			    G_CALLBACK (gpcap_conduits_settings), gpcap);
 
 	/* Row selection signals */
@@ -325,11 +326,11 @@ init_widgets (GnomePilotCapplet *gpcap)
 			  G_CALLBACK (gpcap_conduits_selection_changed), gpcap);
 
 	/* Popup menu signals */
-	g_signal_connect   (GTK_OBJECT (priv->pilots_treeview), "button_press_event",
+	g_signal_connect   (G_OBJECT (priv->pilots_treeview), "button_press_event",
 			    G_CALLBACK (gpcap_pilots_popup), gpcap);
-	g_signal_connect   (GTK_OBJECT (priv->devices_treeview), "button_press_event",
+	g_signal_connect   (G_OBJECT (priv->devices_treeview), "button_press_event",
 			    G_CALLBACK (gpcap_devices_popup), gpcap);
-	g_signal_connect   (GTK_OBJECT (priv->conduit_treeview), "button_press_event",
+	g_signal_connect   (G_OBJECT (priv->conduit_treeview), "button_press_event",
 			    G_CALLBACK (gpcap_conduits_popup), gpcap);
 
 	gtk_widget_show_all (priv->notebook);
@@ -613,7 +614,7 @@ fill_pilots_combo (GnomePilotCapplet *gpcap)
                 tmp = tmp->next;
         }
 
-	g_signal_connect   (GTK_OBJECT(priv->pilots_combo),"changed",
+	g_signal_connect   (G_OBJECT(priv->pilots_combo),"changed",
 		    G_CALLBACK (gpcap_conduits_choose_pilot),
 		    gpcap);
 	gtk_combo_box_set_model (GTK_COMBO_BOX (priv->pilots_combo), GTK_TREE_MODEL(store));
@@ -899,7 +900,7 @@ gpcap_devices_add (GtkWidget *widget, gpointer user_data)
 {
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
-	GtkObject *dlg;
+	GObject *dlg;
 	GPilotDevice *device;
 	gboolean res;
 	
@@ -929,7 +930,7 @@ gpcap_devices_edit (GtkWidget *widget, gpointer user_data)
 {
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
-	GtkObject *dlg;
+	GObject *dlg;
 	GPilotDevice *device;
 	GtkTreeIter iter;
 	gboolean res;
@@ -1344,7 +1345,6 @@ gpcap_dispose (GObject *object)
 {
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (object);
 	GnomePilotCappletPrivate *priv;
-	GtkObjectClass *gppd_class;
 	
 	priv = gpcap->priv;
 
@@ -1365,17 +1365,12 @@ gpcap_dispose (GObject *object)
 		if (priv->conduit_popup)
 			gtk_widget_destroy (priv->conduit_popup);
 
-		/* destroy pilot dialog, if it was loaded */
+		/* unref pilot dialog, if it was loaded */
 		if (priv->pdialog) {
-			gppd_class = g_type_class_peek (gnome_pilot_pdialog_get_type());
-			if (GTK_OBJECT_CLASS (gppd_class)->destroy)
-				GTK_OBJECT_CLASS (gppd_class)->destroy (priv->pdialog);
+			g_object_unref(G_OBJECT(priv->pdialog));
 		}
 		
 		g_free (priv);
 		gpcap->priv = NULL;
 	}
-
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
 }
