@@ -30,7 +30,7 @@
 #include <config.h>
 #include <ctype.h>
 
-#include <gpilotd/gnome-pilot-client.h>
+#include <gnome-pilot-client.h>
 
 #include "gnome-pilot-assistant.h"
 #include "gnome-pilot-capplet.h"
@@ -113,7 +113,7 @@ main (int argc, char *argv[])
 
 	monitor_pilots (gpc, state);
 	if (assistant_on) {
-		GtkObject *assistant;
+		GObject *assistant;
 		
 		if (state->pilots!= NULL || state->devices!= NULL) {
 			error_dialog (NULL, "Cannot run assistant if PDAs or devices already configured"); /* FIXME: Make translatable after string freeze */
@@ -132,7 +132,7 @@ main (int argc, char *argv[])
 
 		/* popup the assistant if nothing is configured - assume this is the first time */
 		if (state->pilots == NULL && state->devices == NULL) {
-			GtkObject *assistant;
+			GObject *assistant;
 			
 			assistant = gnome_pilot_assistant_new (gpc);
 			assistant_finished = gnome_pilot_assistant_run_and_close (GNOME_PILOT_ASSISTANT (assistant));
