@@ -37,10 +37,10 @@
 #include <pi-socket.h>
 #include <pi-dlp.h>
 #include <pi-datebook.h>
-#include <gpilotd/gnome-pilot-conduit.h>
-#include <gpilotd/gnome-pilot-conduit-sync-abs.h>
-#include <libgpilotdCM/gnome-pilot-conduit-management.h>
-#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gnome-pilot-conduit.h>
+#include <gnome-pilot-conduit-sync-abs.h>
+#include <gnome-pilot-conduit-management.h>
+#include <gnome-pilot-conduit-config.h>
 #include <e-pilot-map.h>
 #include <e-pilot-settings.h>
 #include <e-pilot-util.h>
@@ -411,9 +411,7 @@ static gchar *print_remote (GnomePilotRecord *remote)
 {
 	static gchar buff[ 4096 ];
 	struct Appointment appt;
-#ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
-#endif
 
 	if (remote == NULL) {
 		sprintf (buff, "[NULL]");
@@ -421,7 +419,6 @@ static gchar *print_remote (GnomePilotRecord *remote)
 	}
 
 	memset (&appt, 0, sizeof (struct Appointment));
-#ifdef PILOT_LINK_0_12
 	buffer = pi_buffer_new(DLP_BUF_SIZE);
 	if (buffer == NULL) {
 		sprintf (buff, "[NULL]");
@@ -434,9 +431,6 @@ static gchar *print_remote (GnomePilotRecord *remote)
 
 	unpack_Appointment (&appt, buffer, datebook_v1);
 	pi_buffer_free(buffer);
-#else
-	unpack_Appointment (&appt, remote->record, remote->length);
-#endif
 	g_snprintf (buff, 4096, "[%ld %ld '%s' '%s']",
 		    mktime (&appt.begin),
 		    mktime (&appt.end),
@@ -843,11 +837,7 @@ local_record_to_pilot_record (ECalLocalRecord *local,
 			      ECalConduitContext *ctxt)
 {
 	GnomePilotRecord p;
-#ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
-#else
-	static gchar record[0xffff];
-#endif
 
 	memset(&p, 0, sizeof (p));
 
@@ -863,7 +853,6 @@ local_record_to_pilot_record (ECalLocalRecord *local,
 	p.secret = local->local.secret;
 
 	/* Generate pilot record structure */
-#ifdef PILOT_LINK_0_12
 	buffer = pi_buffer_new(DLP_BUF_SIZE);
 	if (buffer == NULL) {
 		pi_set_error(ctxt->dbi->pilot_socket, PI_ERR_GENERIC_MEMORY);
@@ -876,10 +865,6 @@ local_record_to_pilot_record (ECalLocalRecord *local,
 	memcpy(p.record, buffer->data, buffer->used);
 
 	pi_buffer_free(buffer);
-#else
-	p.record = (guchar *)record;
-	p.length = pack_Appointment (local->appt, p.record, 0xffff);
-#endif
 	return p;
 }
 
@@ -915,7 +900,6 @@ local_record_from_comp (ECalLocalRecord *local, ECalComponent *comp, ECalConduit
 	 */
 	if (local->local.ID != 0) {
 		gint cat = 0;
-#ifdef PILOT_LINK_0_12
 		struct Appointment appt;
 		pi_buffer_t * record;
 
@@ -924,34 +908,19 @@ local_record_from_comp (ECalLocalRecord *local, ECalComponent *comp, ECalConduit
 			pi_set_error(ctxt->dbi->pilot_socket, PI_ERR_GENERIC_MEMORY);
 			return;
 		}
-#else
-		struct Appointment appt;
-		gchar record[0xffff];
-#endif
 		if (dlp_ReadRecordById (ctxt->dbi->pilot_socket,
 					ctxt->dbi->db_handle,
-#ifdef PILOT_LINK_0_12
 					local->local.ID, record,
 					NULL, NULL, &cat) > 0) {
-#else
-					local->local.ID, &record,
-					NULL, NULL, NULL, &cat) > 0) {
-#endif
 			local->local.category = cat;
 			memset (&appt, 0, sizeof (struct Appointment));
-#ifdef PILOT_LINK_0_12
 			unpack_Appointment (&appt, record, datebook_v1);
-#else
-			unpack_Appointment (&appt, (guchar *)record, 0xffff);
-#endif
 			local->appt->alarm = appt.alarm;
 			local->appt->advance = appt.advance;
 			local->appt->advanceUnits = appt.advanceUnits;
 			free_Appointment (&appt);
 		}
-#ifdef PILOT_LINK_0_12
 		pi_buffer_free (record);
-#endif
 	}
 
 	/*Category support*/
@@ -1220,12 +1189,9 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 	GSList *edl = NULL;
 	gchar *txt;
 	gint pos, i;
-#ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
-#endif
 	g_return_val_if_fail (remote != NULL, NULL);
 
-#ifdef PILOT_LINK_0_12
 	buffer = pi_buffer_new(DLP_BUF_SIZE);
 	if (buffer == NULL) {
 		return NULL;
@@ -1238,10 +1204,6 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 	unpack_Appointment (&appt, buffer, datebook_v1);
 	pi_buffer_free(buffer);
 
-#else
-	memset (&appt, 0, sizeof (struct Appointment));
-	unpack_Appointment (&appt, remote->record, remote->length);
-#endif
 	if (in_comp == NULL) {
 		comp = e_cal_component_new ();
 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
@@ -1511,21 +1473,17 @@ pre_sync (GnomePilotConduit *conduit,
 	gchar *filename, *change_id;
 	icalcomponent *icalcomp;
 	gint num_records, add_records = 0, mod_records = 0, del_records = 0;
-#ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
-#endif
 	abs_conduit = GNOME_PILOT_CONDUIT_SYNC_ABS (conduit);
 
 	LOG (g_message ( "---------------------------------------------------------\n" ));
 	LOG (g_message ( "pre_sync: Calendar Conduit v.%s", CONDUIT_VERSION ));
 
 	ctxt->dbi = dbi;
-#ifdef PILOT_LINK_0_12
 	if (NULL == dbi->pilotInfo->pilot_charset)
 		ctxt->pilot_charset = NULL;
 	else
 		 ctxt->pilot_charset = g_strdup(dbi->pilotInfo->pilot_charset);
-#endif
 	ctxt->client = NULL;
 
 	/* Get the timezone */
@@ -1627,7 +1585,6 @@ pre_sync (GnomePilotConduit *conduit,
 	gnome_pilot_conduit_sync_abs_set_num_updated_local_records (abs_conduit, mod_records);
 	gnome_pilot_conduit_sync_abs_set_num_deleted_local_records(abs_conduit, del_records);
 
-#ifdef PILOT_LINK_0_12
 	buffer = pi_buffer_new(DLP_BUF_SIZE);
 	if (buffer == NULL) {
 		pi_set_error(dbi->pilot_socket, PI_ERR_GENERIC_MEMORY);
@@ -1637,11 +1594,6 @@ pre_sync (GnomePilotConduit *conduit,
 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
 				DLP_BUF_SIZE,
 				buffer);
-#else
-	buf = (guchar *)g_malloc (0xffff);
-	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
-			      (guchar *)buf, 0xffff);
-#endif
 	if (len < 0) {
 		WARN (_("Could not read pilot's Calendar application block"));
 		WARN ("dlp_ReadAppBlock(...) = %d", len);
@@ -1649,11 +1601,9 @@ pre_sync (GnomePilotConduit *conduit,
 					   _("Could not read pilot's Calendar application block"));
 		return -1;
 	}
-#ifdef PILOT_LINK_0_12
 	buf = g_new0 (unsigned char,buffer->used);
 	memcpy(buf, buffer->data, buffer->used);
 	pi_buffer_free(buffer);
-#endif
 	unpack_AppointmentAppInfo (&(ctxt->ai), buf, len);
 	/* unpack_CategoryAppInfo (&(ctxt->ai.category), buf, len); */
 	g_free (buf);
@@ -2126,7 +2076,7 @@ revert_settings  (GnomePilotConduit *conduit, ECalConduitContext *ctxt)
 GnomePilotConduit *
 conduit_get_gpilot_conduit (guint32 pilot_id)
 {
-	GtkObject *retval;
+	GObject *retval;
 	ECalConduitContext *ctxt;
 
 	LOG (g_message ( "in calendar's conduit_get_gpilot_conduit\n" ));
@@ -2170,11 +2120,11 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 void
 conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 {
-	GtkObject *obj = GTK_OBJECT (conduit);
+	GObject *obj = G_OBJECT (conduit);
 	ECalConduitContext *ctxt;
 
-	ctxt = g_object_get_data (G_OBJECT (obj), "calconduit_context");
+	ctxt = g_object_get_data (obj, "calconduit_context");
 	e_calendar_context_destroy (ctxt);
 
-	gtk_object_destroy (obj);
+	g_object_unref (obj);
 }
