@@ -131,10 +131,10 @@ gnome_pilot_conduit_sync_abs_get_type (void)
 static void
 gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GnomePilotConduitStandardClass *conduit_standard_class;
 
-	object_class = (GtkObjectClass*) klass;
+	object_class = (GObjectClass*) klass;
 	conduit_standard_class = (GnomePilotConduitStandardClass *) klass;
 
 	parent_class = g_type_class_peek (gnome_pilot_conduit_standard_get_type ());
@@ -302,7 +302,7 @@ gnome_pilot_conduit_sync_abs_init (GnomePilotConduitSyncAbs *conduit)
 
 }
 
-GtkObject *
+GObject *
 gnome_pilot_conduit_sync_abs_new (char *db_name,
 				  guint32 creator_id)
 {
@@ -313,7 +313,7 @@ gnome_pilot_conduit_sync_abs_new (char *db_name,
 								"GnomePilotConduitStandard::creator_id", creator_id,
 								NULL));
 
-	return GTK_OBJECT (retval);
+	return G_OBJECT (retval);
 }
 
 /* Local utility routines */
@@ -668,7 +668,7 @@ gnome_pilot_conduit_sync_abs_pre_sync (SyncHandler *sh, int dbhandle, int *slow)
 	
 	dlp_ReadOpenDBInfo (dbinfo->pilot_socket, dbinfo->db_handle, &conduit->total_records);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [PRE_SYNC],
 			 0,
 			 dbinfo,
@@ -689,7 +689,7 @@ gnome_pilot_conduit_sync_abs_post_sync (SyncHandler *sh, int dbhandle)
 	conduit = ((gp_closure *)sh->data)->conduit;
 	dbinfo = ((gp_closure *)sh->data)->dbinfo;
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [POST_SYNC],
 			 0,
 			 dbinfo,
@@ -708,7 +708,7 @@ gnome_pilot_conduit_sync_abs_set_pilot_id (SyncHandler *sh, DesktopRecord *dr, r
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 	
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [SET_PILOT_ID],
 			 0,
 			 gdr, id, &retval);
@@ -729,7 +729,7 @@ gnome_pilot_conduit_sync_abs_set_status_cleared (SyncHandler *sh, DesktopRecord
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 	
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [SET_STATUS_CLEARED],
 			 0,
 			 gdr, &retval);
@@ -748,7 +748,7 @@ gnome_pilot_conduit_sync_abs_for_each (SyncHandler *sh, DesktopRecord **dr)
 
 	conduit = ((gp_closure *)sh->data)->conduit;
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FOR_EACH],
 			 0,
 			 &gdr, &retval);
@@ -770,7 +770,7 @@ gnome_pilot_conduit_sync_abs_for_each_modified (SyncHandler *sh, DesktopRecord *
 
 	conduit = ((gp_closure *)sh->data)->conduit;
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FOR_EACH_MODIFIED],
 			 0,
 			 &gdr, &retval);
@@ -796,7 +796,7 @@ gnome_pilot_conduit_sync_abs_compare (SyncHandler *sh, PilotRecord *pr, DesktopR
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [COMPARE],
 			 0,
 			 gdr, gpr, &retval);
@@ -816,7 +816,7 @@ gnome_pilot_conduit_sync_abs_add_record (SyncHandler *sh, PilotRecord *pr)
 	conduit = ((gp_closure *)sh->data)->conduit;
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [ADD_RECORD],
 			 0,
 			 gpr, &retval);
@@ -839,7 +839,7 @@ gnome_pilot_conduit_sync_abs_replace_record (SyncHandler *sh, DesktopRecord *dr,
 	sync_abs_fill_gdr (gdr);
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [REPLACE_RECORD],
 			 0,
 			 gdr, gpr, &retval);
@@ -860,7 +860,7 @@ gnome_pilot_conduit_sync_abs_delete_record (SyncHandler *sh, DesktopRecord *dr)
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [DELETE_RECORD],
 			 0,
 			 gdr, &retval);
@@ -879,7 +879,7 @@ gnome_pilot_conduit_sync_abs_archive_record (SyncHandler *sh, DesktopRecord *dr,
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [ARCHIVE_RECORD],
 			 0,
 			 gdr, archive ? TRUE : FALSE, &retval);
@@ -900,7 +900,7 @@ gnome_pilot_conduit_sync_abs_match (SyncHandler *sh, PilotRecord *pr, DesktopRec
 	conduit = ((gp_closure *)sh->data)->conduit;
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [MATCH],
 			 0,
 			 gpr, &gdr, &retval);
@@ -926,7 +926,7 @@ gnome_pilot_conduit_sync_abs_free_match (SyncHandler *sh, DesktopRecord *dr)
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FREE_MATCH],
 			 0,
 			 gdr, &retval);
@@ -947,7 +947,7 @@ gnome_pilot_conduit_sync_abs_prepare (SyncHandler *sh, DesktopRecord *dr, PilotR
 	sync_abs_fill_gdr (gdr);
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	g_signal_emit   (GTK_OBJECT (conduit),
+	g_signal_emit   (G_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [PREPARE],
 			 0,
 			 gdr, gpr, &retval);
