@@ -56,9 +56,6 @@
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#ifdef WITH_HAL
-#include <libhal.h>
-#endif
 
 #define GP_DBUS_NAME         "org.gnome.GnomePilot"
 #define GP_DBUS_PATH         "/org/gnome/GnomePilot/Daemon"
@@ -92,16 +89,13 @@ static void load_devices_xml (void);
 static int  known_usb_device (gchar *match_str);
 static gboolean sync_device (GPilotDevice *device, GPilotContext *context);
 
-#ifdef WITH_HAL
-static DBusConnection *dbus_connection = NULL;
-static LibHalContext *hal_ctx = NULL;
-
-static gboolean gpilotd_dbus_init (void);
-static LibHalContext *gpilotd_hal_init (void);
-#endif
+/* move these into GpilotDaemonPrivate... */
+#include <gudev/gudev.h>
+static gboolean gpilotd_gudev_init (void);
+GUdevClient *gudev_client = NULL;
 
 static guint visor_timeout_id = -1;
-static guint hal_initialised = 0;
+static guint udev_initialised = 0;
 static GPtrArray *vendor_product_ids = NULL;
 static GArray *product_net = NULL;
 
@@ -163,15 +157,14 @@ match_pilot_userID (const GPilotPilot   *p,
         return -1;
 }
 
-#ifdef WITH_HAL
-static void
-hal_device_added (LibHalContext *ctx, const char *udi)
-{
+/* function to handle a usb device/vendor ID connection.
+ * used by sysfs, hal, gdbus paths
+ */
+static void usb_device_added (int vendor_id, int product_id) {
 	gboolean visor_net = FALSE;
-	char *bus, *platform, *match_str;
-	int vendor_id, product_id, i;
+	char *match_str;
+	int i;
 	GPilotDevice *device;
-	DBusError error;
 	GList *dev;
         GpilotDaemonPrivate *priv;
 
@@ -182,45 +175,11 @@ hal_device_added (LibHalContext *ctx, const char *udi)
 
 	load_devices_xml ();
 
-	/* HAL match rule: we look for pda.platform == 'palm'
-	 * (or the legacy info.bus == 'usb_device')
-	 * and then try to match the usb_device.product_id and usb_device.vendor_id
-	 * against the list in devices.xml.
-	 */
-	if ((platform = libhal_device_get_property_string (hal_ctx, udi, "pda.platform", NULL))) {
-	    if (strcmp (platform, "palm") != 0) {
-		libhal_free_string (platform);
-		return;
-	    }
-	    libhal_free_string (platform);
-	} else if ((bus = libhal_device_get_property_string (hal_ctx, udi, "info.bus", NULL))) {
-	    if (strcmp (bus, "usb_device") != 0) {
-		libhal_free_string (bus);
-		return;
-	    }
-	    libhal_free_string (bus);
-	} else {
-	    return;
-	}
-
-	dbus_error_init (&error);
-	vendor_id = libhal_device_get_property_int (hal_ctx, udi,
-	    "usb_device.vendor_id", &error);
-	if(vendor_id == -1) {
-		g_warning ("Could not get usb vendor ID from hal: %s", error.message);
-		return;
-	}
-	product_id = libhal_device_get_property_int (hal_ctx, udi,
-	    "usb_device.product_id", NULL);
-	if(product_id == -1) {
-		g_warning ("Could not get usb product ID from hal: %s", error.message);
-		return;
-	}
-	
 	/* now look for a vendor/product match */
 	match_str = g_strdup_printf ("Vendor=%04x ProdID=%04x",
 	    vendor_id, product_id);
 	i = known_usb_device(match_str);
+	g_warning("found match: index=%d looking for: %s\n", i, match_str);
 	g_free(match_str);
 	if(i == -1)
 		return;
@@ -253,131 +212,50 @@ hal_device_added (LibHalContext *ctx, const char *udi)
 	}
 }
 
-static void
-hal_device_removed (LibHalContext *ctx, const char *udi)
+
+static void gpilotd_gudev_handler  (GUdevClient *client, gchar *action, GUdevDevice *device,
+    gpointer user_data)
 {
-	
+	int vendor_id = -1, product_id = -1;
+        GpilotDaemonPrivate *priv;
+	const gchar *s = NULL;
+
+	g_warning ("got usb device: %s", g_udev_device_get_sysfs_path(device));
+
+        priv = GPILOT_DAEMON (daemon_object)->priv;
+
+	if (priv->gpilotd_context->paused) 
+		return;
+	if (g_strncasecmp (action, "add", 3) == 0) {
+		s = g_udev_device_get_property (device, "ID_VENDOR_ID");
+		if (s != NULL)
+			vendor_id = g_ascii_strtoll (s, NULL, 16);
+		s = g_udev_device_get_property (device, "ID_MODEL_ID");
+		if (s != NULL)
+			product_id = g_ascii_strtoll (s, NULL, 16);
+		usb_device_added(vendor_id, product_id);
+	}
 }
 
 static gboolean
-reinit_dbus (gpointer user_data)
+gpilotd_gudev_init (void)
 {
-	if (gpilotd_dbus_init ()) {
-		if ((hal_ctx = gpilotd_hal_init ()))
-			libhal_ctx_set_dbus_connection (hal_ctx, dbus_connection);
-		else
-			exit (1);
-		
-		return FALSE;
-	}
-	
-	return TRUE;
-}
+	const gchar * const udev_subsystems[2] = { "usb/usb_device", NULL};
 
-static DBusHandlerResult
-gpilotd_dbus_filter_function (DBusConnection *connection, DBusMessage *message, void *user_data)
-{
-	if (dbus_message_is_signal (message, DBUS_INTERFACE_LOCAL, "Disconnected") &&
-	    strcmp (dbus_message_get_path (message), DBUS_PATH_LOCAL) == 0) {
-		libhal_ctx_free (hal_ctx);
-		hal_ctx = NULL;
-		
-		dbus_connection_unref (dbus_connection);
-		dbus_connection = NULL;
-		
-		g_timeout_add (3000, reinit_dbus, NULL);
-		
-		return DBUS_HANDLER_RESULT_HANDLED;
-	}
-	
-	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
-}
+	/* Just use g_udev_client / g_udev_device
+	   http://www.kernel.org/pub/linux/utils/kernel/hotplug/gudev/GUdevClient.html
+	*/
 
-static gboolean
-gpilotd_dbus_init (void)
-{
-	DBusError error;
-	
-	if (dbus_connection != NULL)
+	if (gudev_client != NULL)
 		return TRUE;
-	
-	dbus_error_init (&error);
-	if (!(dbus_connection = dbus_bus_get (DBUS_BUS_SYSTEM, &error))) {
-		g_warning ("could not get system bus: %s", error.message);
-		dbus_error_free (&error);
-		return FALSE;
-	}
-	
-	dbus_connection_setup_with_g_main (dbus_connection, NULL);
-	dbus_connection_set_exit_on_disconnect (dbus_connection, FALSE);
-	
-	dbus_connection_add_filter (dbus_connection, gpilotd_dbus_filter_function, NULL, NULL);
+
+	gudev_client = g_udev_client_new (udev_subsystems);
+
+        g_signal_connect (G_OBJECT (gudev_client),"uevent", G_CALLBACK (gpilotd_gudev_handler), NULL);
 	
 	return TRUE;
 }
 
-static LibHalContext *
-gpilotd_hal_init (void)
-{
-	LibHalContext *ctx;
-	DBusError error;
-	char **devices;
-	int nr;
-	
-	if (!gpilotd_dbus_init ()) {
-		g_warning ("failed to initialise DBUS!");
-		return NULL;
-	}
-
-	if (!(ctx = libhal_ctx_new ())) {
-		g_warning ("failed to create a HAL context!");
-		return NULL;
-	}
-	
-	libhal_ctx_set_dbus_connection (ctx, dbus_connection);
-	
-	libhal_ctx_set_device_added (ctx, hal_device_added);
-	libhal_ctx_set_device_removed (ctx, hal_device_removed);
-	/*libhal_ctx_set_device_new_capability (ctx, hal_device_new_capability);*/
-	/*libhal_ctx_set_device_lost_capability (ctx, hal_device_lost_capability);*/
-	/*libhal_ctx_set_device_property_modified (ctx, hal_property_modified);*/
-	/*libhal_ctx_set_device_condition (ctx, hal_device_condition);*/
-	
-	dbus_error_init (&error);
-	if (!libhal_device_property_watch_all (ctx, &error)) {
-		g_warning ("failed to watch all HAL properties!: %s", error.message);
-		dbus_error_free (&error);
-		libhal_ctx_free (ctx);
-		return NULL;
-	}
-	
-	if (!libhal_ctx_init (ctx, &error)) {
-		g_warning ("libhal_ctx_init failed: %s", error.message);
-		dbus_error_free (&error);
-		libhal_ctx_free (ctx);
-		return NULL;
-	}
-	
-	/*
-	 * Do something to ping the HAL daemon - the above functions will
-	 * succeed even if hald is not running, so long as DBUS is.  But we
-	 * want to exit silently if hald is not running, to behave on
-	 * pre-2.6 systems.
-	 */
-	if (!(devices = libhal_get_all_devices (ctx, &nr, &error))) {
-		g_warning ("seems that HAL is not running: %s", error.message);
-		dbus_error_free (&error);
-		
-		libhal_ctx_shutdown (ctx, NULL);
-		libhal_ctx_free (ctx);
-		return NULL;
-	}
-	
-	libhal_free_string_array (devices);
-	
-	return ctx;
-}
-#endif /* WITH_HAL */
 
 static int
 device_equal_by_io (GPilotDevice *dev, GIOChannel *io) 
@@ -421,13 +299,6 @@ pilot_connect (GPilotDevice *device,int *error)
 #define MAX_TIME_FOR_PI_BIND 1000000 /* 1 second, or 1,000,000 usec. */
 #define SLEEP_TIME_FOR_PI_BIND 50000 /* 50 ms */
 	
-#ifndef PILOT_LINK_0_12
-	struct pi_sockaddr addr;
-	union {
-		struct pi_sockaddr *pi_sockaddrp;
-		struct sockaddr *sockaddrp;
-	} addrp;
-#endif
 	int sd, listen_sd, pf;
 	int ret;
 
@@ -463,7 +334,6 @@ pilot_connect (GPilotDevice *device,int *error)
 		 * listening at this point, so move on to accept */
 		listen_sd = device->fd;
 	} else {
-#ifdef PILOT_LINK_0_12
 		/* pl 0.12.0 wants to autodetect the protocol, so pass DLP */
 		/* (at time of writing there's a buglet in pl where if you
 		 * _do_ pass in the correct NET protocol then pl will flush
@@ -471,9 +341,6 @@ pilot_connect (GPilotDevice *device,int *error)
 		 * packet.
 		 */
 		listen_sd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP);
-#else
-		listen_sd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, pf);
-#endif
 		if (listen_sd < 0) {
 			g_warning ("pi_socket returned error %d (%s)",
 			    listen_sd,
@@ -484,8 +351,8 @@ pilot_connect (GPilotDevice *device,int *error)
 
 		
 		/* 
-		 * When using HAL and USB, the ttyUSB[01] device files are
-		 * not created until after Hal has notified gpilotd that
+		 * When using DBUS and USB, the ttyUSB[01] device files are
+		 * not created until after dbus has notified gpilotd that
 		 * a file exists. This causes pi_bind to fail.
 		 * To prevent a failure (and therefore sync), retry pi_bind
 		 * for up to the time allotted, sleeping a little in-between
@@ -494,15 +361,7 @@ pilot_connect (GPilotDevice *device,int *error)
 		
 		time_elapsed_pi_bind = 0;
 		do {
-#ifdef PILOT_LINK_0_12
 			ret = pi_bind (listen_sd, device->port);
-#else
-			addr.pi_family = PI_AF_PILOT;
-			strcpy (addr.pi_device,device->port);
-			addrp.pi_sockaddrp = &addr;
-			ret = pi_bind (listen_sd, addrp.sockaddrp,
-			    sizeof (addr));	
-#endif
 			if(ret < 0) {
 				usleep(SLEEP_TIME_FOR_PI_BIND);
 				time_elapsed_pi_bind += SLEEP_TIME_FOR_PI_BIND;
@@ -544,15 +403,6 @@ pilot_connect (GPilotDevice *device,int *error)
 	if (error)
 		*error = 0;
 
-	/* since pilot-link 0.12.0preX, the listen_sd represents
-	 * the accepted connection, so don't close listen_sd
-	 * after the accept */
-#ifndef PILOT_LINK_0_12
-	if (device->type != PILOT_DEVICE_NETWORK &&
-	    device->type != PILOT_DEVICE_BLUETOOTH) {
-		pi_close(listen_sd);
-	}		
-#endif
 	return sd;
 }
 
@@ -625,7 +475,6 @@ match_pilot_and_majick (const GPilotPilot *pilot,
 static int
 check_usb_config (GPilotDevice *device)
 {
-#ifdef PILOT_LINK_0_12
 #define MAXLINELEN 256
 	char line[MAXLINELEN];
 	gboolean visor_loaded;
@@ -681,9 +530,6 @@ check_usb_config (GPilotDevice *device)
 		error = 1;
 	}
 	return error;
-#else
-        return 0;
-#endif /* PILOT_LINK_0_12 */
 }
 
 
@@ -789,6 +635,7 @@ do_cradle_events (int pfd,
 {
 	GList *events, *it;
 	gboolean ret = TRUE;
+	gchar *pilot_username;
 	
 	/* elements in events freed by gpc_request_purge calls
 	   in dbus_notify_completion */
@@ -808,7 +655,14 @@ do_cradle_events (int pfd,
 		switch (req->type) {
 		case GREQ_SET_USERINFO:
 			g_message (_("Setting userinfo..."));
-			g_snprintf (pu->username,127,"%s", req->parameters.set_userinfo.user_id);
+			/* convert username from UTF-8 to pilot charset */
+			convert_ToPilotChar_WithCharset ("UTF-8",
+					req->parameters.set_userinfo.user_id,
+					strlen(req->parameters.set_userinfo.user_id),
+					&pilot_username, NULL);
+			
+			g_snprintf (pu->username,127,"%s", pilot_username);
+			g_free(pilot_username);
 			pu->userID = req->parameters.set_userinfo.pilot_id;
 			dlp_WriteUserInfo (pfd,pu);
 			if (req->parameters.set_userinfo.continue_sync) {
@@ -960,7 +814,6 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 	struct stat buf; 
 	int ret;
 
-#ifdef PILOT_LINK_0_12
 	iconv_t ic;
 
 	if (pilot->pilot_charset == NULL ||
@@ -995,7 +848,6 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 	 */
 	setenv("PILOT_CHARSET",
 	    pilot->pilot_charset, 1);
-#endif
 
 	ret = stat (pilot->sync_options.basedir, &buf); 
 
@@ -1493,7 +1345,7 @@ visor_devices_timeout (gpointer data)
 #if defined(sun) && defined (__SVR4) /*for solaris */
 	/* On Solaris we always try to sync.  This isn't
 	 * a great solution, but does enable syncing.  We
-	 * should use HAL on Solaris when it is working
+	 * should use dbus on Solaris when it is working
 	 * well.  See bug #385444.
 	 */
        visor_exists = TRUE;
@@ -1555,7 +1407,7 @@ monitor_channel (GPilotDevice *dev, GPilotContext *context)
 		g_assert_not_reached ();
 #endif /* WITH_NETWORK */
 	} if (dev->type == PILOT_DEVICE_USB_VISOR) {
-		if(hal_initialised) {
+		if(udev_initialised) {
 			/* handled by hal callbacks */
 			dev->device_exists = FALSE;
 		} else {
@@ -2543,6 +2395,12 @@ dbus_notify_userinfo (struct PilotUser    user_info,
 
         /* do a strcpy for username to sending sending too long
          string by dbus */
+	/* also, convert from pilot charset to UTF-8 */
+	convert_FromPilotChar_WithCharset ("UTF-8",
+			user_info.username,
+			strlen (user_info.username),
+			&username, NULL );
+
         username = g_strdup (user_info.username);
 
         message = dbus_message_new_signal (GP_DBUS_PATH,
@@ -3025,10 +2883,8 @@ gpilot_daemon_class_init (GpilotDaemonClass *klass)
 static void
 gpilot_daemon_init (GpilotDaemon *daemon)
 {
-#ifdef WITH_HAL
-	if ((hal_ctx = gpilotd_hal_init ()) != NULL)
-		hal_initialised = 1; /* if 0, fall back to polling sysfs */
-#endif
+	gpilotd_gudev_init();
+	udev_initialised = 1;
 	
         daemon->priv = GPILOT_DAEMON_GET_PRIVATE (daemon);
 
